# How-to guides

This part of the project documentation
focuses on a **problem-oriented** approach.
We'll go over how to solve common tasks.


## Data consumers

* ["Example analysis"](analysis_with_a_book)
* ["Find all available books"](find_all_books)

## Data producers

* ["How do I create a new volume?"](create_new_volume)"
